{
  am_pm_abbreviated => [
    "BN",
    "PN",
  ],
  available_formats => {
    Bh => "h'\N{U+00ea}' B",
    Bhm => "h:mm'\N{U+00ea}' B",
    Bhms => "h:mm:ss'\N{U+00ea}' B",
    E => "ccc",
    EBhm => "E, h:mm'\N{U+00ea}' B",
    EBhms => "E, h:mm:ss'\N{U+00ea}' B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E, h:mm'\N{U+00ea}' a",
    Ehms => "E, h:mm:ss'\N{U+00ea}' a",
    Gy => "G y",
    GyMMM => "G MMM'a' y'an'",
    GyMMMEd => "G d'\N{U+00ea}' MMM'a' y'an', E",
    GyMMMd => "G d'\N{U+00ea}' MMM'a' y'an'",
    GyMd => "GGGGG dd.MM.y",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss 'bi' 'dema' v('y')'\N{U+00ea}'",
    Hmv => "HH:mm 'bi' 'dema' v('y')'\N{U+00ea}'",
    M => "L",
    MEd => "E, dd.MM",
    MMM => "LLL",
    MMMEd => "E, d'\N{U+00ea}' MMM'\N{U+00ea}'",
    "MMMMW-count-one" => "'hefteya' W'em' 'ya' MMMM'\N{U+00ea}'",
    "MMMMW-count-other" => "'hefteya' W'em' 'ya' MMMM'\N{U+00ea}'",
    MMMMd => "d'\N{U+00ea}' MMMM'\N{U+00ea}'",
    MMMd => "d'\N{U+00ea}' MMM'\N{U+00ea}'",
    Md => "dd.MM",
    d => "d",
    h => "h'\N{U+00ea}' a",
    hm => "h:mm'\N{U+00ea}' a",
    hms => "h:mm:ss'\N{U+00ea}' a",
    hmsv => "h:mm:ss'\N{U+00ea}' a 'bi' 'dema' v('y')'\N{U+00ea}'",
    hmv => "h:mm'\N{U+00ea}' a 'bi' 'dema' v('y')'\N{U+00ea}'",
    ms => "mm:ss",
    y => "y",
    yM => "MM.y",
    yMEd => "E, dd.MM.y",
    yMMM => "MMM'a' y'an'",
    yMMMEd => "E, d'\N{U+00ea}' MMM'a' y'an'",
    yMMMM => "MMMM'a' y'an'",
    yMMMd => "d'\N{U+00ea}' MMM'a' y'an'",
    yMd => "dd.MM.y",
    yQQQ => "QQQ'em' 'ya' y'an'",
    yQQQQ => "QQQQ 'ya' y'an'",
    "yw-count-one" => "'hefteya' w'em' 'ya' Y'an'",
    "yw-count-other" => "'hefteya' w'em' 'ya' Y'an'",
  },
  code => "ku-TR",
  date_format_full => "EEEE, d'\N{U+00ea}' MMMM'a' y'an'",
  date_format_long => "d'\N{U+00ea}' MMMM'a' y'an'",
  date_format_medium => "d'\N{U+00ea}' MMM'a' y'an'",
  date_format_short => "dd.MM.y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "d\N{U+015f}m",
    "s\N{U+015f}m",
    "\N{U+00e7}\N{U+015f}m",
    "p\N{U+015f}m",
    "\N{U+00ee}n\N{U+00ee}",
    "\N{U+015f}em",
    "y\N{U+015f}m",
  ],
  day_format_narrow => [
    "D",
    "S",
    "\N{U+00c7}",
    "P",
    "\N{U+00ce}",
    "\N{U+015e}",
    "Y",
  ],
  day_format_wide => [
    "du\N{U+015f}em",
    "s\N{U+00ea}\N{U+015f}em",
    "\N{U+00e7}ar\N{U+015f}em",
    "p\N{U+00ea}nc\N{U+015f}em",
    "\N{U+00ee}n\N{U+00ee}",
    "\N{U+015f}em\N{U+00ee}",
    "yek\N{U+015f}em",
  ],
  day_stand_alone_abbreviated => [
    "d\N{U+015f}m",
    "s\N{U+015f}m",
    "\N{U+00e7}\N{U+015f}m",
    "p\N{U+015f}m",
    "\N{U+00ee}n\N{U+00ee}",
    "\N{U+015f}em",
    "y\N{U+015f}m",
  ],
  day_stand_alone_narrow => [
    "D",
    "S",
    "\N{U+00c7}",
    "P",
    "\N{U+00ce}",
    "\N{U+015e}",
    "Y",
  ],
  day_stand_alone_wide => [
    "du\N{U+015f}em",
    "s\N{U+00ea}\N{U+015f}em",
    "\N{U+00e7}ar\N{U+015f}em",
    "p\N{U+00ea}nc\N{U+015f}em",
    "\N{U+00ee}n\N{U+00ee}",
    "\N{U+015f}em\N{U+00ee}",
    "yek\N{U+015f}em",
  ],
  era_abbreviated => [
    "BZ",
    "PZ",
  ],
  era_narrow => [
    "BZ",
    "PZ",
  ],
  era_wide => [
    "ber\N{U+00ee} zay\N{U+00ee}n\N{U+00ea}",
    "pi\N{U+015f}t\N{U+00ee} zay\N{U+00ee}n\N{U+00ea}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%A %d %B %Y",
  glibc_date_format => "%d/%m/%Y",
  glibc_datetime_format => "%A %d %B %Y %T %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Kurdish",
  month_format_abbreviated => [
    "rbn",
    "sbt",
    "adr",
    "nsn",
    "gln",
    "hzr",
    "trm",
    "tbx",
    "\N{U+00ee}ln",
    "cot",
    "mjd",
    "brf",
  ],
  month_format_narrow => [
    "R",
    "S",
    "A",
    "N",
    "G",
    "H",
    "T",
    "T",
    "\N{U+00ce}",
    "C",
    "M",
    "B",
  ],
  month_format_wide => [
    "r\N{U+00ea}bendan",
    "sibat",
    "adar",
    "n\N{U+00ee}san",
    "gulan",
    "hez\N{U+00ee}ran",
    "t\N{U+00ee}rmeh",
    "tebax",
    "\N{U+00ee}lon",
    "cotmeh",
    "mijdar",
    "berfanbar",
  ],
  month_stand_alone_abbreviated => [
    "rbn",
    "sbt",
    "adr",
    "nsn",
    "gln",
    "hzr",
    "trm",
    "tbx",
    "\N{U+00ee}ln",
    "cot",
    "mjd",
    "brf",
  ],
  month_stand_alone_narrow => [
    "R",
    "S",
    "A",
    "N",
    "G",
    "H",
    "T",
    "T",
    "\N{U+00ce}",
    "C",
    "M",
    "B",
  ],
  month_stand_alone_wide => [
    "r\N{U+00ea}bendan",
    "sibat",
    "adar",
    "n\N{U+00ee}san",
    "gulan",
    "hez\N{U+00ee}ran",
    "t\N{U+00ee}rmeh",
    "tebax",
    "\N{U+00ee}lon",
    "cotmeh",
    "mijdar",
    "berfanbar",
  ],
  name => "Kurdish T\N{U+00fc}rkiye",
  native_language => "kurd\N{U+00ee} (kurmanc\N{U+00ee})",
  native_name => "kurd\N{U+00ee} (kurmanc\N{U+00ee}) Tirk\N{U+00ee}ye",
  native_script => undef,
  native_territory => "Tirk\N{U+00ee}ye",
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+00c7}1",
    "\N{U+00c7}2",
    "\N{U+00c7}3",
    "\N{U+00c7}4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+00e7}aryeka 1em",
    "\N{U+00e7}aryeka 2yem",
    "\N{U+00e7}aryeka 3yem",
    "\N{U+00e7}aryeka 4em",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+00c7}1",
    "\N{U+00c7}2",
    "\N{U+00c7}3",
    "\N{U+00c7}4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+00e7}aryeka 1em",
    "\N{U+00e7}aryeka 2yem",
    "\N{U+00e7}aryeka 3yem",
    "\N{U+00e7}aryeka 4em",
  ],
  script => undef,
  territory => "T\N{U+00fc}rkiye",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 46,
}
